import { useEffect, useState } from "react";
import { Link, Route, Routes, useLocation } from "react-router-dom";
import EpisodeDetail from "./components/EpisodeDetail";
import EpisodeList from "./components/EpisodeList";
import FeedDetail from "./components/FeedDetail";
import FeedList from "./components/FeedList";
import FeedManager from "./components/FeedManager";
import RSSEndpoints from "./components/RSSEndpoints";

function App() {
  const location = useLocation();
  const [isDarkMode, setIsDarkMode] = useState(() => {
    const saved = localStorage.getItem("darkMode");
    return saved ? JSON.parse(saved) : false;
  });

  useEffect(() => {
    document.documentElement.setAttribute(
      "data-theme",
      isDarkMode ? "dark" : "light",
    );
    localStorage.setItem("darkMode", JSON.stringify(isDarkMode));
  }, [isDarkMode]);

  const toggleDarkMode = () => {
    setIsDarkMode(!isDarkMode);
  };
  const isMainPage = [
    "/",
    "/feeds",
    "/feed-requests",
    "/rss-endpoints",
  ].includes(location.pathname);

  return (
    <div className="container">
      {isMainPage && (
        <>
          <div className="header">
            <div className="header-content">
              <div className="header-text">
                <div className="title">Voice RSS Summary</div>
                <div className="subtitle">
                  RSS フィードから自動生成された音声ポッドキャスト
                </div>
                <div className="credit">VOICEVOX:冥鳴ひまり</div>
              </div>
              <button
                className="theme-toggle"
                onClick={toggleDarkMode}
                aria-label="テーマを切り替え"
              >
                {isDarkMode ? "☀️" : "🌙"}
              </button>
            </div>
          </div>

          <div className="tabs">
            <Link
              to="/"
              className={`tab ${location.pathname === "/" ? "active" : ""}`}
            >
              エピソード一覧
            </Link>
            <Link
              to="/feeds"
              className={`tab ${location.pathname === "/feeds" ? "active" : ""}`}
            >
              フィード一覧
            </Link>
            <Link
              to="/feed-requests"
              className={`tab ${location.pathname === "/feed-requests" ? "active" : ""}`}
            >
              フィードリクエスト
            </Link>
            <Link
              to="/rss-endpoints"
              className={`tab ${location.pathname === "/rss-endpoints" ? "active" : ""}`}
            >
              RSS配信
            </Link>
          </div>
        </>
      )}

      <div className="content">
        <Routes>
          <Route path="/" element={<EpisodeList />} />
          <Route path="/feeds" element={<FeedList />} />
          <Route path="/feed-requests" element={<FeedManager />} />
          <Route path="/rss-endpoints" element={<RSSEndpoints />} />
          <Route path="/episode/:episodeId" element={<EpisodeDetail />} />
          <Route path="/feeds/:feedId" element={<FeedDetail />} />
        </Routes>
      </div>
    </div>
  );
}

export default App;
